pub struct SuccessEvent {
pub result: Option<String>,
pub id: i64,
}Expand description
Represents a successful event response from the Binance WebSocket API.
Fields
result: Option<String>The optional result of the event, as some events may not return a result.
id: i64The identifier for the event.