pub struct WebSocketConnector { /* private fields */ }Expand description
A connector for establishing WebSocket connections to the Binance WebSocket API.
Implementations
Sourceimpl WebSocketConnector
This struct provides methods to create a new connector and connect to the WebSocket server.
impl WebSocketConnector
This struct provides methods to create a new connector and connect to the WebSocket server.
Examples
use bothan_binance::WebSocketConnector;
let connector = WebSocketConnector::new("wss://example.com/socket");
let connection = connector.connect();Trait Implementations
Sourceimpl AssetInfoProviderConnector for WebSocketConnector
impl AssetInfoProviderConnector for WebSocketConnector
Sourcefn connect<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<WebSocketConnection, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn connect<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<WebSocketConnection, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Connects to the Binance WebSocket API and returns a WebSocketConnection.
Sourcetype Provider = WebSocketConnection
type Provider = WebSocketConnection
The type of provider that this connector creates. Read more